#!/usr/bin/env python
from I3Tray import *
from os.path import expandvars

inphysfile = "test1-filled.i3"
outfile = "juliet-atmofilled.tree.root"
gcsfile = "GCS.i3.gz"

if len(sys.argv) > 1:
	ingcsfile = sys.argv[1]

if len(sys.argv) > 2:
	inphysfile = sys.argv[2]

if len(sys.argv) > 3:
	outfile = sys.argv[3]

load("libicetray")
load("libdataclasses")
load("libphys-services")
load("libsim-services")
load("libdataio")
load("libportia")
load("libweighting-module")
load("libophelia")
load("libehe-star")
load("liblinefit")
load("libtensor-of-inertia")
load("libsim-prod")


tray = I3Tray()


tray.AddService("I3ReaderServiceFactory","i3reader")(
	("FilenameList",
	 [ingcsfile,inphysfile])
	)

tray.AddModule("I3Muxer", "multiplex")

tray.AddModule("I3Portia","pulse")(

  ("DataReadoutName",          "InIceRawData"),

  ("ATWDPulseSeriesName",      "ATWDPulseSeries"),
  ("ATWDPortiaPulseName",      "ATWDPortiaPulse"),
  ("ATWDWaveformName",         "CalibratedATWD"),
  ("ATWDBaseLineOption",       "eheoptimized"),
  ("ATWDThresholdCharge",      0.*I3Units.pC),
  ("ATWDLEThresholdAmplitude", 0.5*I3Units.mV),

  ("UseFADC", True),
  ("FADCPulseSeriesName",      "FADCPulseSeries"),
  ("FADCPortiaPulseName",      "FADCPortiaPulse"),
  ("FADCWaveformName",         "CalibratedFADC"),
  ("FADCBaseLineOption",       "eheoptimized"),
  ("FADCThresholdCharge",      0.*I3Units.pC),
  ("FADCLEThresholdAmplitude", 0.5*I3Units.mV),

  ("MakeBestPulseSeries",      False),
  ("BestPortiaPulseName",      "BestPortiaPulse")
  )

tray.AddModule("I3EHEFirstGuess","reco")(

  ("MinimumNumberPulseDom",  8),
  ("OutputFirstguessName",   "OpheliaFirstGuess"),
  ("InputPulseName1",        "ATWDPortiaPulse"),
  ("InputPulseName2",        "FADCPortiaPulse"),
  ("InputLaunchName",        "InIceRawData"),
  ("ChargeOption",           0),
  ("LCOption",               True),
)

tray.AddModule("I3HyperReco","hyperreco")(
	("PortiaPulseMapNameATWD", "ATWDPortiaPulse"),
	("PortiaPulseMapNameFADC", "FADCPortiaPulse"),
	("OpheliaFirstGuessTrackName", "OpheliaFirstGuess"),
	("InternalFirstGuess", False),
	("MinNCh", 1),
	("OutputHyperTrackName", "HyperTrack")
	)

tray.AddModule("I3OpheliaConvertHyperTrack","convert_hyper")(
        ("InputHyperTrackName", "HyperTrack"),
        ("OutputParticleName", "HyperParticle"),
        )

tray.AddModule("I3EheStarLateralModule","star_cobfg")(
        ("useMCtruth",      True),
        ("useRecoParticle", True),
        ("inMCName", "MCList"),
        ("inRecoParticleName", "HyperParticle"),
	("inAtwdPulseName", "ATWDPortiaPulse"),
        ("inFadcPulseName", "FADCPortiaPulse"),
        #("inBadDomListName", "BadOMSelection"),
	
        ("outEheStarLateralMCName", "EheStarLateralMC"),
        ("outEheStarLateralRecoName", "EheStarLateralReco"),
	("npe_fitMin", 5), # defalt = 10                           
	)

tray.AddModule("I3EheStarFirstDomsModule","star_fg")(
	("inPortiaPulseName", "ATWDPortiaPulse"),
	("outEheStarFirstDomsName", "EheStarFirstDoms"),
	)

tray.AddModule("I3WeigherModuleJulietPlus","weight")(
	
	("doTree",                  True),
	
	("outTreeName",             "JulietTree"),
	("outFileName",             outfile),  
	("inMCListName",           "MCList"),
	("inMCHitSeriesName",      "MCHitSeriesMap"),
	("inDOMLaunchName",        "InIceRawData"),
	#("inDOMLaunchName",        "CleanInIceRawData"),
	("frameMCWeightName", "JulietWeightDict"),
	
	#("doPulseTree",            True),
	("doPulseTree",            False),
	("inAtwdPortiaName",       "ATWDPortiaPulse"),
	("inFadcPortiaName",       "FADCPortiaPulse"),
	
	#("doMCHitTree",            True),
	("doMCHitTree",            False),
	#("McHitCompressionOption", True),
	#("McHitCompressionOption", False),
	
	("doFirstguessTree",       True),
	("inFirstguessName",       "OpheliaFirstGuess"),
	
	("doHyperRecoTree",       True),
	("inHyperRecoName",       "HyperTrack"),

	("doFillWeight",           False),
	("doReWeigh",              False),
	
	("doEheStarTree",          True),
	("inEheStarLateralMCName",   "EheStarLateralMC"),
	("inEheStarLateralRecoName",   "EheStarLateralReco"),

	)

tray.AddModule("TrashCan", "bye")

tray.Execute()
tray.Finish()

